@@ -162,6 +162,7 @@ enum ISMRMRD_AcquisitionFlags {
     ISMRMRD_ACQ_IS_RTFEEDBACK_DATA                  = 28,
     ISMRMRD_ACQ_IS_SURFACECOILCORRECTIONSCAN_DATA   = 29,
 
+
     ISMRMRD_ACQ_COMPRESSION1                        = 53,
     ISMRMRD_ACQ_COMPRESSION2                        = 54,
     ISMRMRD_ACQ_COMPRESSION3                        = 55,
@@ -420,13 +421,13 @@ bool ismrmrd_pop_error(char **file, int *line, char **func,
  *  @{
  */
 /** Calculates the determinant of the matrix and return the sign */
-EXPORTISMRMRD int ismrmrd_sign_of_directions(float read_dir[3], float phase_dir[3], float slice_dir[3]);
+EXPORTISMRMRD int ismrmrd_sign_of_directions(float const read_dir[3], float const phase_dir[3], float const slice_dir[3]);
 
 /** Creates a normalized quaternion from a 3x3 rotation matrix */
-EXPORTISMRMRD void ismrmrd_directions_to_quaternion(float read_dir[3], float phase_dir[3], float slice_dir[3], float quat[4]);
+EXPORTISMRMRD void ismrmrd_directions_to_quaternion(float const read_dir[3], float const phase_dir[3], float const slice_dir[3], float quat[4]);
 
 /** Converts a quaternion of the form | a b c d | to a 3x3 rotation matrix */
-EXPORTISMRMRD void ismrmrd_quaternion_to_directions(float quat[4], float read_dir[3], float phase_dir[3], float slice_dir[3]);
+EXPORTISMRMRD void ismrmrd_quaternion_to_directions(float const quat[4], float read_dir[3], float phase_dir[3], float slice_dir[3]);
 /** @} */
 
 #pragma pack(pop) /* Restore old alignment */
@@ -442,10 +443,14 @@ std::string build_exception_string(void);
 /// Some typedefs to beautify the namespace
 typedef  ISMRMRD_EncodingCounters EncodingCounters;
 
+
 /** @addtogroup cxxapi
  *  @{
  */
 
+
+bool operator==(const EncodingCounters& ec1, const EncodingCounters& ec2);
+
 /// Allowed data types for Images and NDArrays
 template <typename T> EXPORTISMRMRD ISMRMRD_DataTypes get_data_type();
 
@@ -476,14 +481,17 @@ public:
     // Constructors
     AcquisitionHeader();
 
+
+    bool operator==(const AcquisitionHeader& acq) const;
+
     // Flag methods
-    bool isFlagSet(const ISMRMRD_AcquisitionFlags val);
+    bool isFlagSet(const ISMRMRD_AcquisitionFlags val) const;
     void setFlag(const ISMRMRD_AcquisitionFlags val);
     void clearFlag(const ISMRMRD_AcquisitionFlags val);
     void clearAllFlags();
 
     // Channel mask methods
-    bool isChannelActive(uint16_t channel_id);
+    bool isChannelActive(uint16_t channel_id) const;
     void setChannelActive(uint16_t channel_id);
     void setChannelNotActive(uint16_t channel_id);
     void setAllChannelsNotActive();
